package com.framework.mvvm.model.repository

import android.util.Log
import androidx.lifecycle.LiveData
import com.framework.app.api.Api
import com.framework.app.base.IRepository
import com.framework.mvvm.model.data.Data
import com.framework.mvvm.model.data.dataSource
import com.framework.mvvm.model.data.request
import com.framework.mvvm.model.db.AdmDatabase
import com.framework.mvvm.model.db.entity.ProjectEntity
import com.framework.mvvm.model.vo.FrameRequest

class FrameRepository(
    private val api: Api,
    private val db: AdmDatabase
) : IRepository {

    fun getProjects(request: FrameRequest): LiveData<Data<List<ProjectEntity>>> {
        return dataSource(
            fromDb = { db.projectDao().getProjects() },
            fromNt = { request { api.getFrame(request) } },
            onSuccess = { frame ->
                val projects = frame.projects
                val bafs = frame.buildingsAndFloors
                try {
                    db.projectDao().insProject(projects)
                    db.objectDao().insObjects(bafs)
                } catch (e: Exception) {
                    Log.d("IRepository:${FrameRepository::class.simpleName}", e.message!!)
                }
            },
            onFailure = {
                println("onFailure: ${it.msg}")
            }
        )
    }

    fun getProjectsFromDB(): LiveData<List<ProjectEntity>> {
        return db.projectDao().getProjects()
    }

    suspend fun insProject(projects: List<ProjectEntity>) {
        return db.projectDao().insProject(projects)
    }


}